#
# spec file for package qnapi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qnapi
Version:        0.2.3
Release:        7.4
Summary:        A NapiProjekt client
# libmaia and qt-maybe are BSD-2-Clause and BSD-3-Clause respectively
License:        BSD-2-Clause AND GPL-2.0-or-later AND BSD-3-Clause
URL:            https://qnapi.github.io/
Source0:        https://github.com/QNapi/qnapi/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        qnapi-download.desktop
Source2:        qnapi-scan.desktop
Patch0:         qnapi-libmaia.patch
# PATCH-FIX-UPSTREAM qnapi-Qt511.patch
Patch1:         qnapi-Qt511.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5.2
BuildRequires:  pkgconfig(Qt5Gui) >= 5.2
BuildRequires:  pkgconfig(Qt5Network) >= 5.2
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2
BuildRequires:  pkgconfig(Qt5Xml) >= 5.2
BuildRequires:  pkgconfig(libmediainfo)
BuildRequires:  pkgconfig(maia)
BuildRequires:  pkgconfig(zlib)
Recommends:     ffmpeg
# Remove when p7zip-full is in all products
%if 0%{?suse_version} > 1500
Requires:       p7zip-full
%else
Requires:       p7zip
%endif

%description
QNapi is unofficial clone of NapiProjekt program (http://napiprojekt.pl)
written using Qt5. It's focused to be functional on GNU/Linux and other
Unix-like systems, for which NapiProjekt is not available.

%description -l it
QNapi è un clone non ufficiale del programma NapiProjekt (http://napiprojekt.pl)
scritto usando Qt5. È indirizzato alla funzionalità su GNU/Linux ed altri sistemi
simili a Unix, per cui NapiProjekt non è disponibile.

%description -l pl
QNapi jest nieoficjalnym klonem programu NapiProjekt (http://napiprojekt.pl)
napisanym w bibliotece Qt5 z myślą o użytkownikach Linuksa oraz innych
systemów, pod które oryginalny NapiProjekt nie jest dostępny.

%prep
%autosetup -p1

# Fix paths specific for openSUSE
sed -i 's|doc.path = $${INSTALL_PREFIX}/share/doc/qnapi|doc.path = $${INSTALL_PREFIX}/share/doc/packages/qnapi|' qnapi.pro

%build
# fixes gcc6 problem with stdlib headers
%qmake5 QMAKE_DEFAULT_INCDIRS="" %{name}.pro
%make_build

%install
make INSTALL_ROOT=%{buildroot} install %{?_smp_mflags}
# Add Plasma 5 service menu
install -m 644 -D doc/qnapi-download.desktop %{buildroot}%{_datadir}/kservices5/ServiceMenus/qnapi-download.desktop
install -m 644 -D doc/qnapi-scan.desktop %{buildroot}%{_datadir}/kservices5/ServiceMenus/qnapi-scan.desktop
# Add Plasma 6 dolphin service menu
install -m 644 -D %{SOURCE1} %{buildroot}%{_datadir}/kio/servicemenus/qnapi-download.desktop
install -m 644 -D %{SOURCE2} %{buildroot}%{_datadir}/kio/servicemenus/qnapi-scan.desktop

# Fix for "wrong-file-end-of-line-encoding" doc/ChangeLog file
sed -i 's/\r//' doc/ChangeLog

# Put license files in the right place
rm %{buildroot}%{_defaultdocdir}/%{name}/LICENSE*

%fdupes %{buildroot}%{_prefix}
%suse_update_desktop_file -i -r -n %{name} AudioVideo AudioVideoEditing

%files
%doc doc/COPYRIGHT doc/ChangeLog doc/qnapi-download.desktop doc/qnapi-download.schemas doc/qnapi-scan.desktop doc/qnapi-scan.schemas
%license doc/LICENSE doc/LICENSE-pl
%{_bindir}/%{name}
%{_datadir}/icons/*
%{_datadir}/applications/%{name}.desktop
%attr(644,root,root) %{_mandir}/man1/*
%{_mandir}/it/man1/qnapi.1%{?ext_man}
%{_mandir}/pl/man1/qnapi.1%{?ext_man}
%dir %{_datadir}/kservices5
%dir %{_datadir}/kservices5/ServiceMenus
%{_datadir}/kservices5/ServiceMenus/qnapi-download.desktop
%{_datadir}/kservices5/ServiceMenus/qnapi-scan.desktop
%dir %{_datadir}/kio
%dir %{_datadir}/kio/servicemenus
%{_datadir}/kio/servicemenus/qnapi-scan.desktop
%{_datadir}/kio/servicemenus/qnapi-download.desktop

%changelog
* Fri Mar 15 2024 Mariusz Fik <fisiu@opensuse.org>
- Drop service menus for KDE4.
- Add service menus for Plasma 6.
* Tue Feb 20 2024 Christophe Marin <christophe@krop.fr>
- Switch to %%autosetup
- Spec cleanup
* Fri Jun 29 2018 kstreitova@suse.com
- require p7zip-full for TW as 7z and 7za binaries needed by qnapi
  were moved to this package (see bsc#899627 for more details about
  this change)
* Mon Jun 11 2018 aloisio@gmx.com
- Added qnapi-Qt511.patch to fix build with Qt 5.11
* Tue Jan  9 2018 aloisio@gmx.com
- Added missing build dependency
* Sat Jul 29 2017 aloisio@gmx.com
- Added qnapi-libmaia.patch and use the system libmaia instead
  of the embedded one
* Fri Jun  2 2017 aloisio@gmx.com
- Update to version 0.2.3 (machine-translated from Polish):
  * Possibility to select the user interface language
    (english / polish / italian) - (thx Fincer, luigino)
  * Rebuilt application configuration subsystem
  * Split application between library (libqnapi) and user
    interface (gui)
  * Target formatting / caption extension by line argument - # 65
  * Fixed issue with loss of color information for captions during
    conversion - # 100
- Qnapi now includes libmaia and qt-maybe
* Thu Mar 30 2017 aloisio@gmx.com
- Update to version 0.2.2 (machine-translated from Polish):
  * Refreshed application icon
  * Subtitle display of language taken in the summary window
  - # 53 (thx andrewpros)
  * Patch installer for Windows - # 55
  * Improvements in the selection Subtitle - # 57 (thx
    andrewpros)
  * Fix error when changing the diacritical characters to
    ASCII - # 64
  * Prevention segfaultowi - # 83 (thx kempniu)
  * Fixes typos in several places - # 84 (thx kempniu)
  * Configuration Engine Napisy24 - # 88
  * Removed unsupported Napiprojekt engine functions (upload
    Subtitle, reporting of amendments)
  version 0.2.1
  * Problem with the names of paths containing special
    characters also improved when open another instance of
    the application (Windows) - # 28
  * Amendments to the detection of UTF-8 for languages
    other than Polish - # 37
  * The file extension is not changed when processing Subtitle
    is inactive - # 38
  * Showing the version information for Qt
  * Subtitle downloading in the spare language in silent mode
  - # 42
  * Wash libmediainfo instead ffprobe to retrieve information
    about the movie file
  * Subtitle option to search all at once, also in the spare -
    [#] 45
  * Valid only interrupt the search, if found subtitles - # 46
  * Fixes bugs in the engine Napisy24 - # 47
- Added libmediainfo as build requirement
- Added fix for gcc6
* Sat Dec 19 2015 fisiu@opensuse.org
- Update to 0.2.0:
  * bugfix in napisy24 engine
  * icons placed at directories according to their sizes
  * bugfixes in file encoding detection
  * preserving original file encoding during subtitle format conversion
  * bugfixed backup language support
- Drop 0001-fix-license-headers-in-source-files.patch: fixed upstream
- Drop fix-icons-paths.patch: fixed upstream
- Drop qnapi-napisy24.pl-skip-.url.patch: fixed upstream
* Sat Oct 31 2015 fisiu@opensuse.org
- Add qnapi-napisy24.pl-skip-.url.patch: fix napisy24.pl plugin.
* Sat Sep  5 2015 fisiu@opensuse.org
- Update to 1.9.0:
  * conversion between subtitle formas: SRT, mDVD, TMP, MPL2 (requires ffprobe)
  * select target extension of subtitles
  * directory scanning now can see other subtitle extensions than .txt (also .srt and .sub)
  * respect INSTALL_PREFIX on icons and desktop files installation
- Add 0001-fix-license-headers-in-source-files.patch: fix license headers.
- Add fix-icons-paths.patch: fix icons directories.
* Fri Aug 14 2015 fisiu@opensuse.org
- Update to 1.8.0:
  * support for backup language for subtitle download
  * fixed issue with window placing in multi-screen environment
- Update to 1.7.0:
  * new subtitle engine for Napisy24 (by fenuks)
  * migration to Qt5
  * diacritic characters replacement with ASCII counterparts
    in subtitle post-processing
  * GUI/CLI interface improvements
  * lot of minor bugfixes
* Sun Dec 29 2013 fisiu@opensuse.org
- Spec cleanup. It seems qnapi is not maintained anymore,
  but it still works fine.
* Wed Mar  4 2009 fisiu82@gmail.com
- upstream version
* Sat Dec 27 2008 fisiu82@gmail.com
- added service menus for KDE4
* Mon Apr  7 2008 obi.gts@gmail.com
- 0.1.4
* Sat Mar  1 2008 obi.gts@gmail.com
- 0.1.3
* Wed Feb 20 2008 obi.gts@gmail.com
- 0.1.2
* Sat Feb 16 2008 obi.gts@gmail.com
- 0.1.1
